# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .sandbox_status import SandboxStatus


class InitializeSandboxResponse(UniversalBaseModel):
    """
    Response model for sandbox initialization
    """

    sandbox_id: str = pydantic.Field()
    """
    Sandbox identifier
    """

    status: SandboxStatus = pydantic.Field()
    """
    Current status
    """

    message: str = pydantic.Field()
    """
    Initialization result message
    """

    records_created: typing.Optional[typing.Dict[str, typing.Optional[int]]] = pydantic.Field(default=None)
    """
    Count of records created per object type
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
