# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class LogBucket(UniversalBaseModel):
    """
    Cloud Logging bucket - matches API format
    """

    name: str = pydantic.Field()
    """
    Bucket name/ID
    """

    location: typing.Optional[str] = pydantic.Field(default=None)
    """
    Bucket location
    """

    retention_days: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="retentionDays")] = (
        pydantic.Field(default=None)
    )
    """
    Retention period in days
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Bucket description
    """

    create_time: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="createTime")] = pydantic.Field(
        default=None
    )
    """
    Creation timestamp
    """

    update_time: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="updateTime")] = pydantic.Field(
        default=None
    )
    """
    Update timestamp
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
