# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .word_press_post import WordPressPost


class WordPressData(UniversalBaseModel):
    """
    Complete WordPress sandbox data structure

    Note: Posts are created in a single batch without dependencies.
    Future expansion could include pages, media, categories, etc.
    """

    posts: typing.Optional[typing.List[WordPressPost]] = pydantic.Field(default=None)
    """
    List of WordPress posts to create
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
