# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .airtable_data_output import AirtableDataOutput
    from .airtable_field import AirtableField
    from .airtable_record import AirtableRecord
    from .airtable_table import AirtableTable
    from .api_key_auth import ApiKeyAuth
    from .asana_data_output import AsanaDataOutput
    from .asana_project import AsanaProject
    from .asana_story import AsanaStory
    from .asana_task import AsanaTask
    from .azure_ado_auth_error_response import AzureAdoAuthErrorResponse
    from .azure_ado_auth_success_response import AzureAdoAuthSuccessResponse
    from .big_query_dataset import BigQueryDataset
    from .big_query_dataset_reference import BigQueryDatasetReference
    from .big_query_table import BigQueryTable
    from .big_query_table_field_schema import BigQueryTableFieldSchema
    from .big_query_table_reference import BigQueryTableReference
    from .big_query_table_schema import BigQueryTableSchema
    from .calcom_data import CalcomData
    from .calcom_schedule import CalcomSchedule
    from .call_tool_response import CallToolResponse
    from .call_tool_result import CallToolResult
    from .click_up_comment import ClickUpComment
    from .click_up_data_output import ClickUpDataOutput
    from .click_up_folder import ClickUpFolder
    from .click_up_list import ClickUpList
    from .click_up_space import ClickUpSpace
    from .click_up_task import ClickUpTask
    from .close_contact import CloseContact
    from .close_data_output import CloseDataOutput
    from .close_lead import CloseLead
    from .close_opportunity import CloseOpportunity
    from .close_task import CloseTask
    from .compute_instance import ComputeInstance
    from .confluence_comment import ConfluenceComment
    from .confluence_data_output import ConfluenceDataOutput
    from .confluence_page import ConfluencePage
    from .confluence_page_output import ConfluencePageOutput
    from .confluence_space import ConfluenceSpace
    from .connection_type import ConnectionType
    from .create_sandbox_response import CreateSandboxResponse
    from .create_self_hosted_server_response import CreateSelfHostedServerResponse
    from .create_server_response import CreateServerResponse
    from .delete_user_response import DeleteUserResponse
    from .discord_channel import DiscordChannel
    from .discord_data_output import DiscordDataOutput
    from .discord_message import DiscordMessage
    from .discord_reaction import DiscordReaction
    from .dropbox_data import DropboxData
    from .dropbox_file import DropboxFile
    from .dump_sandbox_response_airtable_data import DumpSandboxResponseAirtableData
    from .dump_sandbox_response_asana_data import DumpSandboxResponseAsanaData
    from .dump_sandbox_response_calcom_data import DumpSandboxResponseCalcomData
    from .dump_sandbox_response_click_up_data import DumpSandboxResponseClickUpData
    from .dump_sandbox_response_close_data import DumpSandboxResponseCloseData
    from .dump_sandbox_response_confluence_data import DumpSandboxResponseConfluenceData
    from .dump_sandbox_response_discord_data import DumpSandboxResponseDiscordData
    from .dump_sandbox_response_dropbox_data import DumpSandboxResponseDropboxData
    from .dump_sandbox_response_git_hub_data import DumpSandboxResponseGitHubData
    from .dump_sandbox_response_gmail_data import DumpSandboxResponseGmailData
    from .dump_sandbox_response_google_calendar_data import DumpSandboxResponseGoogleCalendarData
    from .dump_sandbox_response_google_cloud_data import DumpSandboxResponseGoogleCloudData
    from .dump_sandbox_response_google_docs_data import DumpSandboxResponseGoogleDocsData
    from .dump_sandbox_response_google_drive_data import DumpSandboxResponseGoogleDriveData
    from .dump_sandbox_response_google_forms_data import DumpSandboxResponseGoogleFormsData
    from .dump_sandbox_response_google_sheets_data import DumpSandboxResponseGoogleSheetsData
    from .dump_sandbox_response_hub_spot_data import DumpSandboxResponseHubSpotData
    from .dump_sandbox_response_jira_data import DumpSandboxResponseJiraData
    from .dump_sandbox_response_linear_data import DumpSandboxResponseLinearData
    from .dump_sandbox_response_mem0data import DumpSandboxResponseMem0Data
    from .dump_sandbox_response_moneybird_data import DumpSandboxResponseMoneybirdData
    from .dump_sandbox_response_ms_teams_data import DumpSandboxResponseMsTeamsData
    from .dump_sandbox_response_notion_data import DumpSandboxResponseNotionData
    from .dump_sandbox_response_one_drive_data import DumpSandboxResponseOneDriveData
    from .dump_sandbox_response_outlook_calendar_data import DumpSandboxResponseOutlookCalendarData
    from .dump_sandbox_response_outlook_mail_data import DumpSandboxResponseOutlookMailData
    from .dump_sandbox_response_quick_books_data import DumpSandboxResponseQuickBooksData
    from .dump_sandbox_response_resend_data import DumpSandboxResponseResendData
    from .dump_sandbox_response_salesforce_data import DumpSandboxResponseSalesforceData
    from .dump_sandbox_response_shopify_data import DumpSandboxResponseShopifyData
    from .dump_sandbox_response_slack_data import DumpSandboxResponseSlackData
    from .dump_sandbox_response_snowflake_data import DumpSandboxResponseSnowflakeData
    from .dump_sandbox_response_supabase_data import DumpSandboxResponseSupabaseData
    from .dump_sandbox_response_word_press_data import DumpSandboxResponseWordPressData
    from .external_server_info import ExternalServerInfo
    from .external_server_request import ExternalServerRequest
    from .general_auth import GeneralAuth
    from .get_all_users_response import GetAllUsersResponse
    from .get_auth_data_response import GetAuthDataResponse
    from .get_instance_response import GetInstanceResponse
    from .get_mcp_servers_response import GetMcpServersResponse
    from .get_user_auth_response import GetUserAuthResponse
    from .get_user_integrations_response import GetUserIntegrationsResponse
    from .get_user_response import GetUserResponse
    from .git_hub_branch import GitHubBranch
    from .git_hub_data import GitHubData
    from .git_hub_file import GitHubFile
    from .git_hub_folder import GitHubFolder
    from .git_hub_issue import GitHubIssue
    from .git_hub_pull_request import GitHubPullRequest
    from .git_hub_repo import GitHubRepo
    from .gmail_data import GmailData
    from .gmail_draft import GmailDraft
    from .gmail_message import GmailMessage
    from .google_calendar_attendee import GoogleCalendarAttendee
    from .google_calendar_data import GoogleCalendarData
    from .google_calendar_event import GoogleCalendarEvent
    from .google_calendar_event_date_time import GoogleCalendarEventDateTime
    from .google_cloud_data_output import GoogleCloudDataOutput
    from .google_docs_data import GoogleDocsData
    from .google_docs_document import GoogleDocsDocument
    from .google_drive_data import GoogleDriveData
    from .google_drive_file import GoogleDriveFile
    from .google_forms_data import GoogleFormsData
    from .google_forms_form import GoogleFormsForm
    from .google_forms_form_settings import GoogleFormsFormSettings
    from .google_forms_info import GoogleFormsInfo
    from .google_forms_item import GoogleFormsItem
    from .google_forms_quiz_settings import GoogleFormsQuizSettings
    from .google_sheets_cell_value import GoogleSheetsCellValue
    from .google_sheets_data import GoogleSheetsData
    from .google_sheets_grid_data import GoogleSheetsGridData
    from .google_sheets_row_data import GoogleSheetsRowData
    from .google_sheets_sheet import GoogleSheetsSheet
    from .google_sheets_sheet_properties import GoogleSheetsSheetProperties
    from .google_sheets_spreadsheet import GoogleSheetsSpreadsheet
    from .google_sheets_spreadsheet_properties import GoogleSheetsSpreadsheetProperties
    from .http_validation_error import HttpValidationError
    from .hub_spot_company import HubSpotCompany
    from .hub_spot_contact import HubSpotContact
    from .hub_spot_data_output import HubSpotDataOutput
    from .hub_spot_deal import HubSpotDeal
    from .hub_spot_task import HubSpotTask
    from .hub_spot_ticket import HubSpotTicket
    from .initialize_sandbox_response import InitializeSandboxResponse
    from .jira_board import JiraBoard
    from .jira_comment import JiraComment
    from .jira_data_output import JiraDataOutput
    from .jira_issue import JiraIssue
    from .jira_project import JiraProject
    from .jira_sprint import JiraSprint
    from .linear_comment import LinearComment
    from .linear_data import LinearData
    from .linear_issue import LinearIssue
    from .linear_project import LinearProject
    from .list_tools_response import ListToolsResponse
    from .log_bucket import LogBucket
    from .log_entry import LogEntry
    from .log_sink import LogSink
    from .mcp_server import McpServer
    from .mcp_server_name import McpServerName
    from .mem0data_output import Mem0DataOutput
    from .mem0memory import Mem0Memory
    from .mem0message import Mem0Message
    from .moneybird_contact import MoneybirdContact
    from .moneybird_data import MoneybirdData
    from .moneybird_invoice_detail import MoneybirdInvoiceDetail
    from .moneybird_ledger_account import MoneybirdLedgerAccount
    from .moneybird_product import MoneybirdProduct
    from .moneybird_project import MoneybirdProject
    from .moneybird_sales_invoice import MoneybirdSalesInvoice
    from .moneybird_time_entry import MoneybirdTimeEntry
    from .ms_teams_data import MsTeamsData
    from .notion_block import NotionBlock
    from .notion_comment import NotionComment
    from .notion_data_output import NotionDataOutput
    from .notion_data_source import NotionDataSource
    from .notion_database import NotionDatabase
    from .notion_page import NotionPage
    from .o_auth_server_name import OAuthServerName
    from .one_drive_data import OneDriveData
    from .one_drive_file import OneDriveFile
    from .one_drive_folder import OneDriveFolder
    from .outlook_calendar_data import OutlookCalendarData
    from .outlook_calendar_event import OutlookCalendarEvent
    from .outlook_mail_data import OutlookMailData
    from .outlook_mail_message import OutlookMailMessage
    from .override import Override
    from .quick_books_data import QuickBooksData
    from .raw_actions_response import RawActionsResponse
    from .release_sandbox_response import ReleaseSandboxResponse
    from .resend_broadcast import ResendBroadcast
    from .resend_contact import ResendContact
    from .resend_data_output import ResendDataOutput
    from .resend_email import ResendEmail
    from .resend_segment import ResendSegment
    from .reset_sandbox_response import ResetSandboxResponse
    from .salesforce_account import SalesforceAccount
    from .salesforce_campaign import SalesforceCampaign
    from .salesforce_case import SalesforceCase
    from .salesforce_contact import SalesforceContact
    from .salesforce_data import SalesforceData
    from .salesforce_lead import SalesforceLead
    from .salesforce_opportunity import SalesforceOpportunity
    from .sandbox_info import SandboxInfo
    from .sandbox_mcp_server import SandboxMcpServer
    from .sandbox_status import SandboxStatus
    from .server_tool import ServerTool
    from .sharesight_o_auth_error_response import SharesightOAuthErrorResponse
    from .sharesight_o_auth_success_response import SharesightOAuthSuccessResponse
    from .shopify_address import ShopifyAddress
    from .shopify_customer import ShopifyCustomer
    from .shopify_data import ShopifyData
    from .shopify_product import ShopifyProduct
    from .shopify_product_variant import ShopifyProductVariant
    from .slack_channel import SlackChannel
    from .slack_data_output import SlackDataOutput
    from .slack_message import SlackMessage
    from .slack_message_output import SlackMessageOutput
    from .slack_reaction import SlackReaction
    from .snowflake_column import SnowflakeColumn
    from .snowflake_data_output import SnowflakeDataOutput
    from .snowflake_database import SnowflakeDatabase
    from .snowflake_row import SnowflakeRow
    from .snowflake_schema import SnowflakeSchema
    from .snowflake_table import SnowflakeTable
    from .status_response import StatusResponse
    from .storage_bucket import StorageBucket
    from .storage_bucket_lifecycle import StorageBucketLifecycle
    from .storage_bucket_lifecycle_rule import StorageBucketLifecycleRule
    from .storage_bucket_lifecycle_rule_action import StorageBucketLifecycleRuleAction
    from .storage_bucket_lifecycle_rule_condition import StorageBucketLifecycleRuleCondition
    from .storage_bucket_versioning import StorageBucketVersioning
    from .storage_object import StorageObject
    from .strata_add_servers_response import StrataAddServersResponse
    from .strata_create_response import StrataCreateResponse
    from .strata_delete_servers_response import StrataDeleteServersResponse
    from .strata_get_auth_response import StrataGetAuthResponse
    from .strata_get_response import StrataGetResponse
    from .strata_raw_actions_response import StrataRawActionsResponse
    from .supabase_data import SupabaseData
    from .supabase_project import SupabaseProject
    from .supabase_table import SupabaseTable
    from .teams_channel import TeamsChannel
    from .teams_chat import TeamsChat
    from .teams_chat_member import TeamsChatMember
    from .teams_message import TeamsMessage
    from .time_slot import TimeSlot
    from .tool_format import ToolFormat
    from .user_info import UserInfo
    from .validation_error import ValidationError
    from .validation_error_loc_item import ValidationErrorLocItem
    from .white_labeling_response import WhiteLabelingResponse
    from .word_press_data import WordPressData
    from .word_press_post import WordPressPost
    from .zoom_o_auth_error_response import ZoomOAuthErrorResponse
    from .zoom_o_auth_success_response import ZoomOAuthSuccessResponse
_dynamic_imports: typing.Dict[str, str] = {
    "AirtableDataOutput": ".airtable_data_output",
    "AirtableField": ".airtable_field",
    "AirtableRecord": ".airtable_record",
    "AirtableTable": ".airtable_table",
    "ApiKeyAuth": ".api_key_auth",
    "AsanaDataOutput": ".asana_data_output",
    "AsanaProject": ".asana_project",
    "AsanaStory": ".asana_story",
    "AsanaTask": ".asana_task",
    "AzureAdoAuthErrorResponse": ".azure_ado_auth_error_response",
    "AzureAdoAuthSuccessResponse": ".azure_ado_auth_success_response",
    "BigQueryDataset": ".big_query_dataset",
    "BigQueryDatasetReference": ".big_query_dataset_reference",
    "BigQueryTable": ".big_query_table",
    "BigQueryTableFieldSchema": ".big_query_table_field_schema",
    "BigQueryTableReference": ".big_query_table_reference",
    "BigQueryTableSchema": ".big_query_table_schema",
    "CalcomData": ".calcom_data",
    "CalcomSchedule": ".calcom_schedule",
    "CallToolResponse": ".call_tool_response",
    "CallToolResult": ".call_tool_result",
    "ClickUpComment": ".click_up_comment",
    "ClickUpDataOutput": ".click_up_data_output",
    "ClickUpFolder": ".click_up_folder",
    "ClickUpList": ".click_up_list",
    "ClickUpSpace": ".click_up_space",
    "ClickUpTask": ".click_up_task",
    "CloseContact": ".close_contact",
    "CloseDataOutput": ".close_data_output",
    "CloseLead": ".close_lead",
    "CloseOpportunity": ".close_opportunity",
    "CloseTask": ".close_task",
    "ComputeInstance": ".compute_instance",
    "ConfluenceComment": ".confluence_comment",
    "ConfluenceDataOutput": ".confluence_data_output",
    "ConfluencePage": ".confluence_page",
    "ConfluencePageOutput": ".confluence_page_output",
    "ConfluenceSpace": ".confluence_space",
    "ConnectionType": ".connection_type",
    "CreateSandboxResponse": ".create_sandbox_response",
    "CreateSelfHostedServerResponse": ".create_self_hosted_server_response",
    "CreateServerResponse": ".create_server_response",
    "DeleteUserResponse": ".delete_user_response",
    "DiscordChannel": ".discord_channel",
    "DiscordDataOutput": ".discord_data_output",
    "DiscordMessage": ".discord_message",
    "DiscordReaction": ".discord_reaction",
    "DropboxData": ".dropbox_data",
    "DropboxFile": ".dropbox_file",
    "DumpSandboxResponseAirtableData": ".dump_sandbox_response_airtable_data",
    "DumpSandboxResponseAsanaData": ".dump_sandbox_response_asana_data",
    "DumpSandboxResponseCalcomData": ".dump_sandbox_response_calcom_data",
    "DumpSandboxResponseClickUpData": ".dump_sandbox_response_click_up_data",
    "DumpSandboxResponseCloseData": ".dump_sandbox_response_close_data",
    "DumpSandboxResponseConfluenceData": ".dump_sandbox_response_confluence_data",
    "DumpSandboxResponseDiscordData": ".dump_sandbox_response_discord_data",
    "DumpSandboxResponseDropboxData": ".dump_sandbox_response_dropbox_data",
    "DumpSandboxResponseGitHubData": ".dump_sandbox_response_git_hub_data",
    "DumpSandboxResponseGmailData": ".dump_sandbox_response_gmail_data",
    "DumpSandboxResponseGoogleCalendarData": ".dump_sandbox_response_google_calendar_data",
    "DumpSandboxResponseGoogleCloudData": ".dump_sandbox_response_google_cloud_data",
    "DumpSandboxResponseGoogleDocsData": ".dump_sandbox_response_google_docs_data",
    "DumpSandboxResponseGoogleDriveData": ".dump_sandbox_response_google_drive_data",
    "DumpSandboxResponseGoogleFormsData": ".dump_sandbox_response_google_forms_data",
    "DumpSandboxResponseGoogleSheetsData": ".dump_sandbox_response_google_sheets_data",
    "DumpSandboxResponseHubSpotData": ".dump_sandbox_response_hub_spot_data",
    "DumpSandboxResponseJiraData": ".dump_sandbox_response_jira_data",
    "DumpSandboxResponseLinearData": ".dump_sandbox_response_linear_data",
    "DumpSandboxResponseMem0Data": ".dump_sandbox_response_mem0data",
    "DumpSandboxResponseMoneybirdData": ".dump_sandbox_response_moneybird_data",
    "DumpSandboxResponseMsTeamsData": ".dump_sandbox_response_ms_teams_data",
    "DumpSandboxResponseNotionData": ".dump_sandbox_response_notion_data",
    "DumpSandboxResponseOneDriveData": ".dump_sandbox_response_one_drive_data",
    "DumpSandboxResponseOutlookCalendarData": ".dump_sandbox_response_outlook_calendar_data",
    "DumpSandboxResponseOutlookMailData": ".dump_sandbox_response_outlook_mail_data",
    "DumpSandboxResponseQuickBooksData": ".dump_sandbox_response_quick_books_data",
    "DumpSandboxResponseResendData": ".dump_sandbox_response_resend_data",
    "DumpSandboxResponseSalesforceData": ".dump_sandbox_response_salesforce_data",
    "DumpSandboxResponseShopifyData": ".dump_sandbox_response_shopify_data",
    "DumpSandboxResponseSlackData": ".dump_sandbox_response_slack_data",
    "DumpSandboxResponseSnowflakeData": ".dump_sandbox_response_snowflake_data",
    "DumpSandboxResponseSupabaseData": ".dump_sandbox_response_supabase_data",
    "DumpSandboxResponseWordPressData": ".dump_sandbox_response_word_press_data",
    "ExternalServerInfo": ".external_server_info",
    "ExternalServerRequest": ".external_server_request",
    "GeneralAuth": ".general_auth",
    "GetAllUsersResponse": ".get_all_users_response",
    "GetAuthDataResponse": ".get_auth_data_response",
    "GetInstanceResponse": ".get_instance_response",
    "GetMcpServersResponse": ".get_mcp_servers_response",
    "GetUserAuthResponse": ".get_user_auth_response",
    "GetUserIntegrationsResponse": ".get_user_integrations_response",
    "GetUserResponse": ".get_user_response",
    "GitHubBranch": ".git_hub_branch",
    "GitHubData": ".git_hub_data",
    "GitHubFile": ".git_hub_file",
    "GitHubFolder": ".git_hub_folder",
    "GitHubIssue": ".git_hub_issue",
    "GitHubPullRequest": ".git_hub_pull_request",
    "GitHubRepo": ".git_hub_repo",
    "GmailData": ".gmail_data",
    "GmailDraft": ".gmail_draft",
    "GmailMessage": ".gmail_message",
    "GoogleCalendarAttendee": ".google_calendar_attendee",
    "GoogleCalendarData": ".google_calendar_data",
    "GoogleCalendarEvent": ".google_calendar_event",
    "GoogleCalendarEventDateTime": ".google_calendar_event_date_time",
    "GoogleCloudDataOutput": ".google_cloud_data_output",
    "GoogleDocsData": ".google_docs_data",
    "GoogleDocsDocument": ".google_docs_document",
    "GoogleDriveData": ".google_drive_data",
    "GoogleDriveFile": ".google_drive_file",
    "GoogleFormsData": ".google_forms_data",
    "GoogleFormsForm": ".google_forms_form",
    "GoogleFormsFormSettings": ".google_forms_form_settings",
    "GoogleFormsInfo": ".google_forms_info",
    "GoogleFormsItem": ".google_forms_item",
    "GoogleFormsQuizSettings": ".google_forms_quiz_settings",
    "GoogleSheetsCellValue": ".google_sheets_cell_value",
    "GoogleSheetsData": ".google_sheets_data",
    "GoogleSheetsGridData": ".google_sheets_grid_data",
    "GoogleSheetsRowData": ".google_sheets_row_data",
    "GoogleSheetsSheet": ".google_sheets_sheet",
    "GoogleSheetsSheetProperties": ".google_sheets_sheet_properties",
    "GoogleSheetsSpreadsheet": ".google_sheets_spreadsheet",
    "GoogleSheetsSpreadsheetProperties": ".google_sheets_spreadsheet_properties",
    "HttpValidationError": ".http_validation_error",
    "HubSpotCompany": ".hub_spot_company",
    "HubSpotContact": ".hub_spot_contact",
    "HubSpotDataOutput": ".hub_spot_data_output",
    "HubSpotDeal": ".hub_spot_deal",
    "HubSpotTask": ".hub_spot_task",
    "HubSpotTicket": ".hub_spot_ticket",
    "InitializeSandboxResponse": ".initialize_sandbox_response",
    "JiraBoard": ".jira_board",
    "JiraComment": ".jira_comment",
    "JiraDataOutput": ".jira_data_output",
    "JiraIssue": ".jira_issue",
    "JiraProject": ".jira_project",
    "JiraSprint": ".jira_sprint",
    "LinearComment": ".linear_comment",
    "LinearData": ".linear_data",
    "LinearIssue": ".linear_issue",
    "LinearProject": ".linear_project",
    "ListToolsResponse": ".list_tools_response",
    "LogBucket": ".log_bucket",
    "LogEntry": ".log_entry",
    "LogSink": ".log_sink",
    "McpServer": ".mcp_server",
    "McpServerName": ".mcp_server_name",
    "Mem0DataOutput": ".mem0data_output",
    "Mem0Memory": ".mem0memory",
    "Mem0Message": ".mem0message",
    "MoneybirdContact": ".moneybird_contact",
    "MoneybirdData": ".moneybird_data",
    "MoneybirdInvoiceDetail": ".moneybird_invoice_detail",
    "MoneybirdLedgerAccount": ".moneybird_ledger_account",
    "MoneybirdProduct": ".moneybird_product",
    "MoneybirdProject": ".moneybird_project",
    "MoneybirdSalesInvoice": ".moneybird_sales_invoice",
    "MoneybirdTimeEntry": ".moneybird_time_entry",
    "MsTeamsData": ".ms_teams_data",
    "NotionBlock": ".notion_block",
    "NotionComment": ".notion_comment",
    "NotionDataOutput": ".notion_data_output",
    "NotionDataSource": ".notion_data_source",
    "NotionDatabase": ".notion_database",
    "NotionPage": ".notion_page",
    "OAuthServerName": ".o_auth_server_name",
    "OneDriveData": ".one_drive_data",
    "OneDriveFile": ".one_drive_file",
    "OneDriveFolder": ".one_drive_folder",
    "OutlookCalendarData": ".outlook_calendar_data",
    "OutlookCalendarEvent": ".outlook_calendar_event",
    "OutlookMailData": ".outlook_mail_data",
    "OutlookMailMessage": ".outlook_mail_message",
    "Override": ".override",
    "QuickBooksData": ".quick_books_data",
    "RawActionsResponse": ".raw_actions_response",
    "ReleaseSandboxResponse": ".release_sandbox_response",
    "ResendBroadcast": ".resend_broadcast",
    "ResendContact": ".resend_contact",
    "ResendDataOutput": ".resend_data_output",
    "ResendEmail": ".resend_email",
    "ResendSegment": ".resend_segment",
    "ResetSandboxResponse": ".reset_sandbox_response",
    "SalesforceAccount": ".salesforce_account",
    "SalesforceCampaign": ".salesforce_campaign",
    "SalesforceCase": ".salesforce_case",
    "SalesforceContact": ".salesforce_contact",
    "SalesforceData": ".salesforce_data",
    "SalesforceLead": ".salesforce_lead",
    "SalesforceOpportunity": ".salesforce_opportunity",
    "SandboxInfo": ".sandbox_info",
    "SandboxMcpServer": ".sandbox_mcp_server",
    "SandboxStatus": ".sandbox_status",
    "ServerTool": ".server_tool",
    "SharesightOAuthErrorResponse": ".sharesight_o_auth_error_response",
    "SharesightOAuthSuccessResponse": ".sharesight_o_auth_success_response",
    "ShopifyAddress": ".shopify_address",
    "ShopifyCustomer": ".shopify_customer",
    "ShopifyData": ".shopify_data",
    "ShopifyProduct": ".shopify_product",
    "ShopifyProductVariant": ".shopify_product_variant",
    "SlackChannel": ".slack_channel",
    "SlackDataOutput": ".slack_data_output",
    "SlackMessage": ".slack_message",
    "SlackMessageOutput": ".slack_message_output",
    "SlackReaction": ".slack_reaction",
    "SnowflakeColumn": ".snowflake_column",
    "SnowflakeDataOutput": ".snowflake_data_output",
    "SnowflakeDatabase": ".snowflake_database",
    "SnowflakeRow": ".snowflake_row",
    "SnowflakeSchema": ".snowflake_schema",
    "SnowflakeTable": ".snowflake_table",
    "StatusResponse": ".status_response",
    "StorageBucket": ".storage_bucket",
    "StorageBucketLifecycle": ".storage_bucket_lifecycle",
    "StorageBucketLifecycleRule": ".storage_bucket_lifecycle_rule",
    "StorageBucketLifecycleRuleAction": ".storage_bucket_lifecycle_rule_action",
    "StorageBucketLifecycleRuleCondition": ".storage_bucket_lifecycle_rule_condition",
    "StorageBucketVersioning": ".storage_bucket_versioning",
    "StorageObject": ".storage_object",
    "StrataAddServersResponse": ".strata_add_servers_response",
    "StrataCreateResponse": ".strata_create_response",
    "StrataDeleteServersResponse": ".strata_delete_servers_response",
    "StrataGetAuthResponse": ".strata_get_auth_response",
    "StrataGetResponse": ".strata_get_response",
    "StrataRawActionsResponse": ".strata_raw_actions_response",
    "SupabaseData": ".supabase_data",
    "SupabaseProject": ".supabase_project",
    "SupabaseTable": ".supabase_table",
    "TeamsChannel": ".teams_channel",
    "TeamsChat": ".teams_chat",
    "TeamsChatMember": ".teams_chat_member",
    "TeamsMessage": ".teams_message",
    "TimeSlot": ".time_slot",
    "ToolFormat": ".tool_format",
    "UserInfo": ".user_info",
    "ValidationError": ".validation_error",
    "ValidationErrorLocItem": ".validation_error_loc_item",
    "WhiteLabelingResponse": ".white_labeling_response",
    "WordPressData": ".word_press_data",
    "WordPressPost": ".word_press_post",
    "ZoomOAuthErrorResponse": ".zoom_o_auth_error_response",
    "ZoomOAuthSuccessResponse": ".zoom_o_auth_success_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AirtableDataOutput",
    "AirtableField",
    "AirtableRecord",
    "AirtableTable",
    "ApiKeyAuth",
    "AsanaDataOutput",
    "AsanaProject",
    "AsanaStory",
    "AsanaTask",
    "AzureAdoAuthErrorResponse",
    "AzureAdoAuthSuccessResponse",
    "BigQueryDataset",
    "BigQueryDatasetReference",
    "BigQueryTable",
    "BigQueryTableFieldSchema",
    "BigQueryTableReference",
    "BigQueryTableSchema",
    "CalcomData",
    "CalcomSchedule",
    "CallToolResponse",
    "CallToolResult",
    "ClickUpComment",
    "ClickUpDataOutput",
    "ClickUpFolder",
    "ClickUpList",
    "ClickUpSpace",
    "ClickUpTask",
    "CloseContact",
    "CloseDataOutput",
    "CloseLead",
    "CloseOpportunity",
    "CloseTask",
    "ComputeInstance",
    "ConfluenceComment",
    "ConfluenceDataOutput",
    "ConfluencePage",
    "ConfluencePageOutput",
    "ConfluenceSpace",
    "ConnectionType",
    "CreateSandboxResponse",
    "CreateSelfHostedServerResponse",
    "CreateServerResponse",
    "DeleteUserResponse",
    "DiscordChannel",
    "DiscordDataOutput",
    "DiscordMessage",
    "DiscordReaction",
    "DropboxData",
    "DropboxFile",
    "DumpSandboxResponseAirtableData",
    "DumpSandboxResponseAsanaData",
    "DumpSandboxResponseCalcomData",
    "DumpSandboxResponseClickUpData",
    "DumpSandboxResponseCloseData",
    "DumpSandboxResponseConfluenceData",
    "DumpSandboxResponseDiscordData",
    "DumpSandboxResponseDropboxData",
    "DumpSandboxResponseGitHubData",
    "DumpSandboxResponseGmailData",
    "DumpSandboxResponseGoogleCalendarData",
    "DumpSandboxResponseGoogleCloudData",
    "DumpSandboxResponseGoogleDocsData",
    "DumpSandboxResponseGoogleDriveData",
    "DumpSandboxResponseGoogleFormsData",
    "DumpSandboxResponseGoogleSheetsData",
    "DumpSandboxResponseHubSpotData",
    "DumpSandboxResponseJiraData",
    "DumpSandboxResponseLinearData",
    "DumpSandboxResponseMem0Data",
    "DumpSandboxResponseMoneybirdData",
    "DumpSandboxResponseMsTeamsData",
    "DumpSandboxResponseNotionData",
    "DumpSandboxResponseOneDriveData",
    "DumpSandboxResponseOutlookCalendarData",
    "DumpSandboxResponseOutlookMailData",
    "DumpSandboxResponseQuickBooksData",
    "DumpSandboxResponseResendData",
    "DumpSandboxResponseSalesforceData",
    "DumpSandboxResponseShopifyData",
    "DumpSandboxResponseSlackData",
    "DumpSandboxResponseSnowflakeData",
    "DumpSandboxResponseSupabaseData",
    "DumpSandboxResponseWordPressData",
    "ExternalServerInfo",
    "ExternalServerRequest",
    "GeneralAuth",
    "GetAllUsersResponse",
    "GetAuthDataResponse",
    "GetInstanceResponse",
    "GetMcpServersResponse",
    "GetUserAuthResponse",
    "GetUserIntegrationsResponse",
    "GetUserResponse",
    "GitHubBranch",
    "GitHubData",
    "GitHubFile",
    "GitHubFolder",
    "GitHubIssue",
    "GitHubPullRequest",
    "GitHubRepo",
    "GmailData",
    "GmailDraft",
    "GmailMessage",
    "GoogleCalendarAttendee",
    "GoogleCalendarData",
    "GoogleCalendarEvent",
    "GoogleCalendarEventDateTime",
    "GoogleCloudDataOutput",
    "GoogleDocsData",
    "GoogleDocsDocument",
    "GoogleDriveData",
    "GoogleDriveFile",
    "GoogleFormsData",
    "GoogleFormsForm",
    "GoogleFormsFormSettings",
    "GoogleFormsInfo",
    "GoogleFormsItem",
    "GoogleFormsQuizSettings",
    "GoogleSheetsCellValue",
    "GoogleSheetsData",
    "GoogleSheetsGridData",
    "GoogleSheetsRowData",
    "GoogleSheetsSheet",
    "GoogleSheetsSheetProperties",
    "GoogleSheetsSpreadsheet",
    "GoogleSheetsSpreadsheetProperties",
    "HttpValidationError",
    "HubSpotCompany",
    "HubSpotContact",
    "HubSpotDataOutput",
    "HubSpotDeal",
    "HubSpotTask",
    "HubSpotTicket",
    "InitializeSandboxResponse",
    "JiraBoard",
    "JiraComment",
    "JiraDataOutput",
    "JiraIssue",
    "JiraProject",
    "JiraSprint",
    "LinearComment",
    "LinearData",
    "LinearIssue",
    "LinearProject",
    "ListToolsResponse",
    "LogBucket",
    "LogEntry",
    "LogSink",
    "McpServer",
    "McpServerName",
    "Mem0DataOutput",
    "Mem0Memory",
    "Mem0Message",
    "MoneybirdContact",
    "MoneybirdData",
    "MoneybirdInvoiceDetail",
    "MoneybirdLedgerAccount",
    "MoneybirdProduct",
    "MoneybirdProject",
    "MoneybirdSalesInvoice",
    "MoneybirdTimeEntry",
    "MsTeamsData",
    "NotionBlock",
    "NotionComment",
    "NotionDataOutput",
    "NotionDataSource",
    "NotionDatabase",
    "NotionPage",
    "OAuthServerName",
    "OneDriveData",
    "OneDriveFile",
    "OneDriveFolder",
    "OutlookCalendarData",
    "OutlookCalendarEvent",
    "OutlookMailData",
    "OutlookMailMessage",
    "Override",
    "QuickBooksData",
    "RawActionsResponse",
    "ReleaseSandboxResponse",
    "ResendBroadcast",
    "ResendContact",
    "ResendDataOutput",
    "ResendEmail",
    "ResendSegment",
    "ResetSandboxResponse",
    "SalesforceAccount",
    "SalesforceCampaign",
    "SalesforceCase",
    "SalesforceContact",
    "SalesforceData",
    "SalesforceLead",
    "SalesforceOpportunity",
    "SandboxInfo",
    "SandboxMcpServer",
    "SandboxStatus",
    "ServerTool",
    "SharesightOAuthErrorResponse",
    "SharesightOAuthSuccessResponse",
    "ShopifyAddress",
    "ShopifyCustomer",
    "ShopifyData",
    "ShopifyProduct",
    "ShopifyProductVariant",
    "SlackChannel",
    "SlackDataOutput",
    "SlackMessage",
    "SlackMessageOutput",
    "SlackReaction",
    "SnowflakeColumn",
    "SnowflakeDataOutput",
    "SnowflakeDatabase",
    "SnowflakeRow",
    "SnowflakeSchema",
    "SnowflakeTable",
    "StatusResponse",
    "StorageBucket",
    "StorageBucketLifecycle",
    "StorageBucketLifecycleRule",
    "StorageBucketLifecycleRuleAction",
    "StorageBucketLifecycleRuleCondition",
    "StorageBucketVersioning",
    "StorageObject",
    "StrataAddServersResponse",
    "StrataCreateResponse",
    "StrataDeleteServersResponse",
    "StrataGetAuthResponse",
    "StrataGetResponse",
    "StrataRawActionsResponse",
    "SupabaseData",
    "SupabaseProject",
    "SupabaseTable",
    "TeamsChannel",
    "TeamsChat",
    "TeamsChatMember",
    "TeamsMessage",
    "TimeSlot",
    "ToolFormat",
    "UserInfo",
    "ValidationError",
    "ValidationErrorLocItem",
    "WhiteLabelingResponse",
    "WordPressData",
    "WordPressPost",
    "ZoomOAuthErrorResponse",
    "ZoomOAuthSuccessResponse",
]
