# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from ..core.serialization import FieldMetadata
from .big_query_dataset import BigQueryDataset
from .big_query_table import BigQueryTable
from .compute_instance import ComputeInstance
from .log_bucket import LogBucket
from .log_entry import LogEntry
from .log_sink import LogSink
from .storage_bucket import StorageBucket
from .storage_object import StorageObject


class GoogleCloudDataOutput(UniversalBaseModel):
    """
    Complete Google Cloud sandbox data structure
    """

    datasets: typing.Optional[typing.List[BigQueryDataset]] = pydantic.Field(default=None)
    """
    BigQuery datasets
    """

    tables: typing.Optional[typing.List[BigQueryTable]] = pydantic.Field(default=None)
    """
    BigQuery tables
    """

    buckets: typing.Optional[typing.List[StorageBucket]] = pydantic.Field(default=None)
    """
    Cloud Storage buckets
    """

    objects: typing.Optional[typing.List[StorageObject]] = pydantic.Field(default=None)
    """
    Cloud Storage objects
    """

    log_entries: typing_extensions.Annotated[
        typing.Optional[typing.List[LogEntry]], FieldMetadata(alias="logEntries")
    ] = pydantic.Field(default=None)
    """
    Log entries
    """

    log_sinks: typing_extensions.Annotated[typing.Optional[typing.List[LogSink]], FieldMetadata(alias="logSinks")] = (
        pydantic.Field(default=None)
    )
    """
    Log sinks
    """

    log_buckets: typing_extensions.Annotated[
        typing.Optional[typing.List[LogBucket]], FieldMetadata(alias="logBuckets")
    ] = pydantic.Field(default=None)
    """
    Log buckets
    """

    instances: typing.Optional[typing.List[ComputeInstance]] = pydantic.Field(default=None)
    """
    Compute Engine instances
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(GoogleCloudDataOutput)
