# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class StorageBucketLifecycleRuleAction(UniversalBaseModel):
    """
    Action for a lifecycle rule
    """

    type: str = pydantic.Field()
    """
    Action type (Delete, SetStorageClass)
    """

    storage_class: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="storageClass")] = (
        pydantic.Field(default=None)
    )
    """
    Storage class for SetStorageClass action
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
