# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class BigQueryTableFieldSchema(UniversalBaseModel):
    """
    Schema for a BigQuery table field
    """

    name: str = pydantic.Field()
    """
    Field name
    """

    type: str = pydantic.Field()
    """
    Field type (STRING, INTEGER, FLOAT, BOOLEAN, TIMESTAMP, RECORD, etc.)
    """

    mode: typing.Optional[str] = pydantic.Field(default=None)
    """
    Field mode (NULLABLE, REQUIRED, REPEATED)
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Field description
    """

    fields: typing.Optional[typing.List["BigQueryTableFieldSchema"]] = pydantic.Field(default=None)
    """
    Nested fields for RECORD type
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(BigQueryTableFieldSchema)
