# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .teams_channel import TeamsChannel
from .teams_chat import TeamsChat


class MsTeamsData(UniversalBaseModel):
    """
    Complete Microsoft Teams sandbox data structure
    """

    channels: typing.Optional[typing.List[TeamsChannel]] = pydantic.Field(default=None)
    """
    List of team channels
    """

    chats: typing.Optional[typing.List[TeamsChat]] = pydantic.Field(default=None)
    """
    List of one-on-one chats
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
