# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .discord_message import DiscordMessage


class DiscordChannel(UniversalBaseModel):
    """
    Discord Channel - uses existing channel by ID
    """

    channel_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Discord channel ID (auto-discovered if not provided)
    """

    messages: typing.Optional[typing.List[DiscordMessage]] = pydantic.Field(default=None)
    """
    Messages in this channel
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
