# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SandboxStatus(str, enum.Enum):
    """
    Status of a sandbox instance - matches database enum
    """

    IDLE = "idle"
    OCCUPIED = "occupied"

    def visit(self, idle: typing.Callable[[], T_Result], occupied: typing.Callable[[], T_Result]) -> T_Result:
        if self is SandboxStatus.IDLE:
            return idle()
        if self is SandboxStatus.OCCUPIED:
            return occupied()
