# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .google_forms_quiz_settings import GoogleFormsQuizSettings


class GoogleFormsFormSettings(UniversalBaseModel):
    """
    Form settings - matches API FormSettings object
    """

    quiz_settings: typing_extensions.Annotated[
        typing.Optional[GoogleFormsQuizSettings], FieldMetadata(alias="quizSettings")
    ] = pydantic.Field(default=None)
    """
    Settings related to quiz forms
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
