# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .click_up_folder import ClickUpFolder
from .click_up_list import ClickUpList


class ClickUpSpace(UniversalBaseModel):
    """
    ClickUp Space object
    """

    name: str = pydantic.Field()
    """
    Space name
    """

    folders: typing.Optional[typing.List[ClickUpFolder]] = pydantic.Field(default=None)
    """
    Folders in this space
    """

    lists: typing.Optional[typing.List[ClickUpList]] = pydantic.Field(default=None)
    """
    Folderless lists in this space
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
