# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.mcp_server_name import McpServerName

DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem = typing.Union[
    McpServerName, typing.Literal["ALL"]
]
