# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CloseOpportunity(UniversalBaseModel):
    """
    Close Opportunity object - child of Lead
    """

    note: str = pydantic.Field()
    """
    Opportunity note/description
    """

    value: typing.Optional[int] = pydantic.Field(default=None)
    """
    Opportunity value in cents
    """

    confidence: typing.Optional[int] = pydantic.Field(default=None)
    """
    Confidence percentage (0-100)
    """

    value_period: typing.Optional[str] = pydantic.Field(default=None)
    """
    Value period (e.g., 'one_time', 'monthly', 'annual')
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
