# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class OneDriveData(UniversalBaseModel):
    """
    Complete OneDrive sandbox data structure
    """

    root: "OneDriveFolder" = pydantic.Field()
    """
    Root folder containing all subfolders and files
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .one_drive_folder import OneDriveFolder  # noqa: E402, I001

update_forward_refs(OneDriveData)
